%source: https://github.com/stochasticresearch/copula/tree/master/algorithms/R_ports_helpers

function [ y ] = logserrnd(n, p)
% Performs the same as LOGSERRND above, but this is the way it was
% implemented in the copula package in R.

y = zeros(n,1);
thresh = 0.95;

if(length(p)==1)
    p = repmat(p, n, 1);
end

for nn=1:n
    if(p(nn)<thresh)
        y(nn) = logserrnd_LS ( p(nn) );
    else
        y(nn) = logserrnd_LK ( p(nn) );
    end
    
end

end

function [ y ] = logserrnd_LS( alpha )
    t = - alpha / log(1 - alpha);
    u = rand();
    p = t;
    x = 1;
    while (u > p) 
        u = u - p;
        x = x + 1;
        p = p * alpha * (x - 1) / x;
    end
    y = x;
end

function [ y ] = logserrnd_LK( alpha )

    h = log(1 - alpha);
    u2 = rand();
    x = 1.0;
    if ( u2 > alpha ) 
        y = fix(x);     % used to be int(x)
    else 
        u1 = rand;
        q = 1 - exp(u1 * h);
        if ( u2 < q * q ) 
            y = fix(1 + log(u2) / log(q));
        elseif ( u2 > q ) 
            y = 1;
        else
            y = 2;
        end
    end

end